@@ -1,10 +1,10 @@
 /*
-  Copyright (C) 2006 Werner Dittmann
+  Copyright (C) 2006-2007 Werner Dittmann
 
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2, or (at your option)
-  any later version.
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Boston, MA 02111.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef _ZRTPPACKETERROR_H_
@@ -37,14 +36,15 @@ class ZrtpPacketError : public ZrtpPacketBase {
 
  public:
     ZrtpPacketError();		/* Creates a Error packet with default data */
-    ZrtpPacketError(char* data);	/* Creates a Error packet from received data */
+    ZrtpPacketError(uint8_t* data);	/* Creates a Error packet from received data */
     virtual ~ZrtpPacketError();
 
-    uint8_t* getErrorType() { return errorHeader->type; };
+    uint32_t getErrorCode() { return ntohl(errorHeader->errorCode); };
 
-    void setErrorType(uint8_t *text) { memcpy(errorHeader->type, text, 8); };
+    void setErrorCode(uint32_t code) {errorHeader->errorCode = htonl(code); };
 
  private:
+     ErrorPacket_t data;
 };
 
 #endif // ZRTPPACKETERROR
