@@ -40,6 +40,11 @@ static gcry_mpi_t bnP4096MinusOne = NULL;
 
 static uint8_t dhinit = 0;
 
+void randomZRTP(uint8_t *buf, int32_t length) {
+    initializeGcrypt();
+    gcry_randomize(buf, length, GCRY_STRONG_RANDOM);
+}
+
 static const uint8_t P3072[] =
     {
 	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC9, 0x0F, 0xDA, 0xA2,
@@ -123,7 +128,7 @@ static const uint8_t P4096[] =
 	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF
 };
 
-ZrtpDH::ZrtpDH(int32_t pl) {
+ZrtpDH::ZrtpDH(int32_t pl): pkLength(pl) {
 
     ctx = static_cast<void*>(new gcryptCtx);
     gcryptCtx* tmpCtx = static_cast<gcryptCtx*>(ctx);
@@ -137,9 +142,10 @@ ZrtpDH::ZrtpDH(int32_t pl) {
         gcry_mpi_scan(&bnP4096, GCRYMPI_FMT_USG, P4096, sizeof(P4096), NULL);
         two = gcry_mpi_set_ui(NULL, 2);
         bnP3072MinusOne = gcry_mpi_new(sizeof(P3072)*8);
+        gcry_mpi_sub_ui(bnP3072MinusOne, bnP3072, 1);
         bnP4096MinusOne = gcry_mpi_new(sizeof(P4096)*8);
         gcry_mpi_sub_ui(bnP4096MinusOne, bnP4096, 1);
-	dhinit = 1;
+        dhinit = 1;
     }
 
     tmpCtx->pLength = pl;
@@ -214,10 +220,6 @@ int32_t ZrtpDH::getPubKeySize() const
     return ((gcry_mpi_get_nbits(static_cast<gcryptCtx*>(ctx)->pubKey) + 7) / 8);
 }
 
-void ZrtpDH::random(uint8_t *buf, int32_t length) {
-    gcry_randomize(buf, length, GCRY_STRONG_RANDOM);
-}
-
 int32_t ZrtpDH::checkPubKey(uint8_t *pubKeyBytes,
                             int32_t length) const
 {
